@@ -83,6 +83,7 @@ def backup_db(ctx, config, filename, dbname, dumptype, column_inserts):
                 )
             )
         conn = config.get_odoo_conn()
+        version = None
         version = _get_postgres_version(conn)
         Commands.invoke(ctx, "stop", machines=["postgres"])
         path = json.loads(
@@ -193,10 +194,9 @@ def _get_postgres_version(conn):
     return version
 
 
-def _restore_wodoo_bin(ctx, config, filepath):
+def _restore_wodoo_bin(ctx, config, filepath, verify):
     if not config.run_postgres:
         abort("WODOO-BIN files may only be restored if RUN_POSTGRES=1")
-    Commands.invoke(ctx, "up", daemon=True, machines=["postgres"])
     with open(filepath, "rb") as file:
         content = file.read(1024)
         count_lineendings = 0
@@ -207,11 +207,14 @@ def _restore_wodoo_bin(ctx, config, filepath):
                 count_lineendings += 1
             if count_lineendings == 2:
                 break
-    postgres_version = content.decode("utf-8", errors="ignore").split("\n")[1].strip()
-    conn = config.get_odoo_conn()
-    version = _get_postgres_version(conn)
-    if version != postgres_version:
-        abort(f"Version mismatch: {version} != {postgres_version}")
+    if verify:
+        Commands.invoke(ctx, 'up', daemon=True, machines=['postgres'])
+        postgres_version = content.decode(
+            'utf-8', errors='ignore').split("\n")[1].strip()
+        conn = config.get_odoo_conn()
+        version = _get_postgres_version(conn)
+        if version != postgres_version:
+            abort(f"Version mismatch: {version} != {postgres_version}")
 
     assert config.run_postgres
     Commands.invoke(ctx, "down")
@@ -228,29 +231,27 @@ def _restore_wodoo_bin(ctx, config, filepath):
     )
     mountpoint = volume[0]["Mountpoint"]
     with autocleanpaper() as scriptfile:
-        scriptfile.write_text(
-            (
-                "#!/bin/bash\n"
-                "set -e\n"
-                f"rm -Rf '{mountpoint}'\n"
-                f"mkdir '{mountpoint}'\n"
-                f"cd '{mountpoint}'\n"
-                f"dd if={filepath} bs=1 skip={cutoff} | "
-                f"pigz -dc | tar x\n"
-            )
-        )
+        scriptfile.write_text((
+            "#!/bin/bash\n"
+            "set -e\n"
+            f"rm -Rf '{mountpoint}'\n"
+            f"mkdir '{mountpoint}'\n"
+            f"cd '{mountpoint}'\n"
+            f"tail '{filepath}' -c +{cutoff + 1} | "
+            f"pigz -dc | tar x\n"
+        ))
         subprocess.check_call(["/bin/bash", scriptfile])
     Commands.invoke(ctx, "up", machines=["postgres"], daemon=True)
 
-
-@restore.command(name="odoo-db")
-@click.argument("filename", required=False, default="")
-@click.option("--latest", default=False, is_flag=True, help="Restore latest dump")
-@click.option("--no-dev-scripts", default=False, is_flag=True)
-@click.option("--no-remove-webassets", default=False, is_flag=True)
+@restore.command(name='odoo-db')
+@click.argument('filename', required=False, default='')
+@click.option('--latest', default=False, is_flag=True, help="Restore latest dump")
+@click.option('--no-dev-scripts', default=False, is_flag=True)
+@click.option('--no-remove-webassets', default=False, is_flag=True)
+@click.option('--verify', default=False, is_flag=True)
 @pass_config
 @click.pass_context
-def restore_db(ctx, config, filename, latest, no_dev_scripts, no_remove_webassets):
+def restore_db(ctx, config, filename, latest, no_dev_scripts, no_remove_webassets, verify):
     if not filename:
         filename = _inquirer_dump_file(
             config, "Choose filename to restore", config.dbname, latest=latest
@@ -278,7 +279,7 @@ def restore_db(ctx, config, filename, latest, no_dev_scripts, no_remove_webasset
         filename = Path(filename_absolute).name
 
     if dump_type.startswith("wodoo_bin"):
-        _restore_wodoo_bin(ctx, config, filename_absolute)
+        _restore_wodoo_bin(ctx, config, filename_absolute, verify)
 
     else:
         if config.run_postgres:
